#!/bin/bash

# check for root permissions
if [ $(id -u) != 0 ]; then
    echo "Builds scripts need root permissions, but you don't seem to have them.
    Become a local god using sudo, then we'll work together to build the future." > /dev/stderr
    exit 1
fi

# check for dependencies
dependency_list='dctrl-tools dpkg-dev genisoimage gfxboot-theme-ubuntu live-build squashfs-tools syslinux syslinux-themes-elementary-isis zsync'
for package in $dependency_list; do
    dpkg -L "$package" >/dev/null 2>&1 || missing_dependencies="$missing_dependencies $package"
done

if [ "$missing_dependencies" != "" ]; then
    echo "Missing dependencies! Please install the following packages:
    $missing_dependencies" > /dev/stderr
    exit 1
fi

build() {
    working_dir="/var/congrego"
    mkdir -p $working_dir &> /dev/null

    # load config
    congrego_conf_location=$working_dir/etc/congrego.conf
    source $congrego_conf_location

    ARCH=${1:-'i386'}

    # create temporary directories
    tmp_dir=$working_dir/tmp
    tmp_working_arch_dir=$tmp_dir/$ARCH
    mkdir -p $tmp_working_arch_dir &> /dev/null

    # We're a lengthy background process, so don't eat too much CPU and disk I/O
    if [[ "$LOW_PRIORITY" == "yes" ]]; then
	    renice '+15' $$ || true
	    ionice -c 3 -p $$ || true
    fi

    cp -R $working_dir/etc/auto $tmp_working_arch_dir/

    sed -i "s/@ARCH/$ARCH/" $tmp_working_arch_dir/auto/config
    sed -i "s/@SYSLINUX/$CODENAME/" $tmp_working_arch_dir/auto/config
    sed -i "s/@WORKING_CHANNEL/$CHANNEL/" $tmp_working_arch_dir/auto/config
    sed -i "s/@WORKING_CODENAME/$BASECODENAME/" $tmp_working_arch_dir/auto/config
    sed -i "s/@VERSION/$VERSION/" $tmp_working_arch_dir/auto/hooks/info.binary
    sed -i "s/@CODENAME/$CODENAME/" $tmp_working_arch_dir/auto/hooks/info.binary
    sed -i "s/@CHANNEL/$CHANNEL/" $tmp_working_arch_dir/auto/hooks/info.binary
    sed -i "s/@ARCH/$ARCH/" $tmp_working_arch_dir/auto/hooks/info.binary
    sed -i "s/@ARCH/$ARCH/" $tmp_working_arch_dir/auto/hooks/iso.binary
    sed -i "s/@BASEVERSION/$BASEVERSION/" $tmp_working_arch_dir/auto/hooks/iso.binary
    sed -i "s/@BASECODENAME/$BASECODENAME/" $tmp_working_arch_dir/auto/hooks/iso.binary
    sed -i "s/@CHANGELOG/$CHANGELOG/" $tmp_working_arch_dir/auto/hooks/iso.binary
    sed -i "s/@VERSION/$VERSION/" $tmp_working_arch_dir/auto/hooks/iso.binary
    sed -i "s/@CODENAME/$CODENAME/" $tmp_working_arch_dir/auto/hooks/iso.binary

    # run live-build
    cd $tmp_working_arch_dir
    lb clean
    lb config
    lb build

    # YYYYMMDD
    build_date=`date +%Y%m%d`

    # create destination directory
    working_arch_build_dir=$tmp_dir/builds/$build_date/$ARCH
    mkdir -p $working_arch_build_dir &> /dev/null

    # final iso filename and location
    target_iso_filename="elementaryos-unstable-$ARCH.$build_date.iso"
    target_iso_filelocation=$working_arch_build_dir/$target_iso_filename

    # move and rename temporary iso
    mv $tmp_working_arch_dir/binary.hybrid.iso $target_iso_filelocation

    # create md5 checksum
    md5sum $target_iso_filelocation > $target_iso_filelocation'.md5'

    if [[ "$OUTPUTDIR" != "" ]]; then # begin optional destination change

        mkdir -p $OUTPUTDIR &> /dev/null
        mv $target_iso_filelocation $target_iso_filelocation.md5 $OUTPUTDIR

    fi # end optional destination change

    if [[ "$SOURCEFORGE" != "" ]]; then # begin optional sourceforge upload

        # create zsync file
        zsyncmake -e \
        -o "$working_arch_build_dir/$target_iso_filename"'.zsync' \
        -u 'http://superb-sea2.dl.sourceforge.net/project/elementaryos/unstable/'"$target_iso_filename" \
        -u 'http://heanet.dl.sourceforge.net/project/elementaryos/unstable/'"$target_iso_filename" \
        -u 'http://ignum.dl.sourceforge.net/project/elementaryos/unstable/'"$target_iso_filename" \
        -u 'http://citylan.dl.sourceforge.net/project/elementaryos/unstable/'"$target_iso_filename" \
        "$target_iso_filelocation"

        # avoid ssh timeout by waiting for user input
        read -p "Press [Enter] to continue."

        # upload created iso and zsync files
        scp $target_iso_filelocation $target_iso_filelocation.zsync $SOURCEFORGE@frs.sourceforge.net:/home/frs/project/elementaryos/unstable/

    fi # end optional sourceforge upload

    # remove temporary files
    rm -Rf $tmp_working_arch_dir/auto
    rm -f $tmp_working_arch_dir/livecd*
}

if [[ "$ARCH" == "all" ]]; then
	build i386
	build amd64
else
	build "$ARCH"
fi
